@@ -24,7 +24,7 @@
 #include <stdarg.h>
 #include <ctype.h>
 #include <stdlib.h>
-#ifdef BROKEN_STRTOD
+#if HAVE_BROKEN_STRTOD
 # define strtod good_strtod
 #endif
 namespace Efont {
