@@ -4,7 +4,7 @@
  * Eddie Kohler
  *
  * Copyright (c) 1999-2000 Massachusetts Institute of Technology
- * Copyright (c) 2001-2010 Eddie Kohler
+ * Copyright (c) 2001-2011 Eddie Kohler
  * Copyright (c) 2008 Meraki, Inc.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -486,14 +486,8 @@ ErrorHandler::vxformat(int default_flags, const char *s, va_list val)
 	    int len;
 	    if (precision < 0)
 		len = strlen(s1);
-	    else {
-#if HAVE_STRNLEN
+	    else
 		len = strnlen(s1, precision);
-#else
-		for (len = 0; len < precision && s1[len] != 0; ++len)
-		    /* do nothing */;
-#endif
-	    }
 
 	    // transform string if alternate form
 	    if (flags & cf_alternate_form) {
